@@ -209,13 +209,15 @@ def count_input_paths(metadata_item):
 
 
 def collate_metadata(metadata_dict):
-    return tuple(
-        g for k, g in sorted(
-            (k, tuple(g)) for k, g in groupby(
-                generate_collated_metadata(metadata_dict), key=count_input_paths
-            )
+    meta = sorted(
+        (k, tuple(g)) for k, g in groupby(
+            generate_collated_metadata(metadata_dict), key=count_input_paths
         )
     )
+    meta_se = tuple(g for k, g in meta if k == 1)
+    meta_pe = tuple(g for k, g in meta if k == 2)
+    return meta_se, meta_pe
+
 
 
 def get_genotypes(
@@ -330,6 +332,9 @@ def get_genotypes(
             
             if n_metadata > 0:
                 meta_se, meta_pe = collate_metadata(metadata_dict)
+                print(meta_se)
+                print(meta_pe)
+                raise SystemExit()
                 if len(meta_se) > 0:
                     metadata_quasar_input_paths_se = pool.starmap(
                         partial(
@@ -344,7 +349,7 @@ def get_genotypes(
                     metadata_quasar_input_paths_pe = pool.starmap(
                         partial(
                             prepare_quasar_input_from_metadata,
-                            **prepare_quasar_input_params(temp_dir_name, len(meta_pe), pe=False)
+                            **prepare_quasar_input_params(temp_dir_name, len(meta_pe), pe=True)
                         ),
                         meta_pe
                     )
